/*
 * Copyright (C) 2007-2011 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib/gprintf.h>
#include <stdlib.h>

#include "libappstarter/as.h"

#define PLUGIN "displaydemo"

enum {
    CHOICE_PRESENTATION = 0,
    CHOICE_CLOCK
};

gchar *cmd = NULL;
gchar *conffile;

guint choice;

GtkWidget *presentation_btn, *clock_btn;

static void
read_config ()
{
    XfceRc *rc;

    rc = as_rc_open (conffile, TRUE);
    if (!rc)
        return;

    xfce_rc_set_group (rc, PLUGIN);
    choice = xfce_rc_read_int_entry (rc, "selected", CHOICE_PRESENTATION);
    xfce_rc_close (rc);
}

static void
write_config (GtkWidget *widget, gpointer data)
{
    XfceRc *rc;

    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (presentation_btn)))
        choice = CHOICE_PRESENTATION;
    else
        choice = CHOICE_CLOCK;

    rc = as_rc_open (conffile, FALSE);
    if (!rc)
        return;

    xfce_rc_set_group (rc, PLUGIN);
    xfce_rc_write_int_entry (rc, "selected", choice);
    xfce_rc_close (rc);
}

GtkWidget *
get_config_widget (gchar *file)
{
    GtkWidget *vbox;
    GtkWidget *label;

    conffile = g_strdup (file);
    read_config ();

    vbox = gtk_vbox_new (FALSE, 2);

    label = gtk_label_new (_("This plugin will display a demonstration using a "
                             "local web page.\nThe pages can be customized for "
                             "other purpose."));
    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 2);

    presentation_btn = gtk_radio_button_new_with_label (NULL,
        _("Presentation demonstration and Clock"));
    gtk_box_pack_start (GTK_BOX (vbox), presentation_btn, FALSE, FALSE, 0);
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (presentation_btn),
        (choice == CHOICE_PRESENTATION) ? TRUE : FALSE);

    clock_btn = gtk_radio_button_new_with_label_from_widget (
        GTK_RADIO_BUTTON (presentation_btn), _("Clock"));
    gtk_box_pack_start (GTK_BOX (vbox), clock_btn, FALSE, FALSE, 0);
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (clock_btn),
        (choice == CHOICE_CLOCK) ? TRUE : FALSE);

    g_signal_connect (G_OBJECT (presentation_btn), "toggled",
        G_CALLBACK (write_config), NULL);
    g_signal_connect (G_OBJECT (clock_btn), "toggled",
        G_CALLBACK (write_config), NULL);

    gtk_widget_show_all (vbox);

    return vbox;
}

gchar *
get_cmd()
{
    gboolean active;

    active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (presentation_btn));

    g_free (cmd);
    cmd = g_strconcat ("firefox /cdrom/webpages/", active ? "index.html" : "clock.html", NULL);
    return cmd;
}

void
free_all()
{
    g_free (conffile);
    g_free (cmd);
}
